changeset 90039:67146244da43

New coding system aliases unix, dos, and mac.
author Kenichi Handa <handa@m17n.org>
date Thu, 28 Oct 2004 02:07:08 +0000
parents 3a5b83e18d41
children e30d01a249dd
files lisp/international/mule-conf.el
diffstat 1 files changed, 11 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/mule-conf.el	Wed Oct 27 06:03:07 2004 +0000
+++ b/lisp/international/mule-conf.el	Thu Oct 28 02:07:08 2004 +0000
@@ -1167,15 +1167,22 @@
 
 ;;; Make fundamental coding systems.
 
 ;; The coding system `no-conversion' is already defined in coding.c as
 ;; below:
 ;;
 ;; (define-coding-system 'no-conversion
-;;   "Do no conversion."
+;;   "..."
 ;;   :coding-type 'raw-text
-;;   :mnemonic ?=)
+;;   ...)
+;; (define-coding-system 'undecided
+;;   "..."
+;;   :coding-type 'undecided
+;;   ...)
 
 (define-coding-system-alias 'binary 'no-conversion)
+(define-coding-system-alias 'unix 'undecided-unix)
+(define-coding-system-alias 'dos 'undecided-dos)
+(define-coding-system-alias 'mac 'undecided-mac)
 
 (define-coding-system 'raw-text
   "Raw text, which means text contains random 8-bit codes.
@@ -1167,15 +1167,22 @@
 ;;; Make fundamental coding systems.
 
-;; The coding system `no-conversion' is already defined in coding.c as
-;; below:
+;; The coding system `no-conversion' and `undecided' are already
+;; defined in coding.c as below:
 ;;
 ;; (define-coding-system 'no-conversion